/*+
|                                                   |
|          Procedure: ETL_FINANCEIROGER             |
|                                                   |
|      Rotina para insero de dados de BI -        |
|      Contas a pagar / pagas e                     |
|      Contas a receber / recebidas.                |
|                                                   |
|            Tabelas Preenchidas:                   |
|                                                   |
|        1:   ETLCONTAPAG - Pagamento		    |
|        2:   ETLCONTAREC - Recebimento             |
|                                                   |
|     Criao:                                      |
|     06/03/2008 - Leandro Corra Gonalves         |
|                                                   |
|     Modificao:                                  |
|     29/04/2008 - Leandro Corra Gonalves         |
|                                                   |
|  *Correo de Valores validados de acordo com os  |
|          Relatrios PAG11001 E REC11001           | 
|                                                   |
+*/


IF EXISTS(SELECT name FROM sysobjects
          WHERE name = 'ETL_FINANCEIROGER')
   DROP PROCEDURE ETL_FINANCEIROGER
GO

CREATE PROCEDURE ETL_FINANCEIROGER
                     (@P_DTINI      DATETIME,
                      @P_DTFINA     DATETIME)
AS
   DECLARE  @V_DTFIM           DATETIME;
   DECLARE  @V_DTINI           DATETIME;
   DECLARE  @V_COUNTER         NUMERIC;
   DECLARE  @V_DTINICIALBI     DATETIME;

/*   -----VARIAVEIS CURSOR C_ETL-----*/

   DECLARE @V_MES             VARCHAR(02);
   DECLARE @V_ANO             VARCHAR(04);
   DECLARE @V_BIM             VARCHAR(06);
   DECLARE @V_TRI             VARCHAR(06);
   DECLARE @V_SEM             VARCHAR(06);
   DECLARE @V_DTMOV           VARCHAR(10);
   DECLARE @V_CDAREAGERE      VARCHAR(03);
   DECLARE @V_CDSUPERVISOR    VARCHAR(12);
   DECLARE @V_CDGOPERAC       VARCHAR(12);
   DECLARE @V_CDSEGMER        VARCHAR(05);

 /* -----VARIAVEIS CURSOR C_PAGA-----*/

   DECLARE @VRORIGPAG         DOUBLE PRECISION;
   DECLARE @VRPAGAVENCER      DOUBLE PRECISION;
   DECLARE @VRPAGVENCIDAS     DOUBLE PRECISION;
   DECLARE @VRCTPAGARREAL     DOUBLE PRECISION;
   DECLARE @VRCTPAGARPREV     DOUBLE PRECISION;
   DECLARE @VRACPAG           DOUBLE PRECISION;
   DECLARE @VRDCPAG           DOUBLE PRECISION;
   DECLARE @VRABERTOPAG       DOUBLE PRECISION;
   
   DECLARE @CDFILIAL          VARCHAR(04);
   DECLARE @CDFORNECED        VARCHAR(21);
   DECLARE @CDEMPRESA         VARCHAR(02);
   DECLARE @CDTPCTPAGAR       VARCHAR(06);
   DECLARE @CDCLASSFINA       VARCHAR(06);
   DECLARE @DTETLMOVPAG      DATETIME;

 /* -----VARIAVEIS CURSOR C_RECEB-----*/
   DECLARE  @VRRECEBIDO      DOUBLE PRECISION;
   DECLARE  @VRABERTOREC     DOUBLE PRECISION;
   DECLARE  @VRORIGREC       DOUBLE PRECISION;
   DECLARE  @VRACREC         DOUBLE PRECISION;
   DECLARE  @VRAREC          DOUBLE PRECISION;
   DECLARE  @VRREC           DOUBLE PRECISION;
   DECLARE  @VRDCREC         DOUBLE PRECISION;
   DECLARE  @VRCTRECARREAL   DOUBLE PRECISION;
   DECLARE  @VRCTRECPREV     DOUBLE PRECISION;
   DECLARE  @VRRECAVENCER    DOUBLE PRECISION;
   DECLARE  @VRRECVENCIDAS   DOUBLE PRECISION;
   DECLARE  @CDTPCTRECEB     VARCHAR(06);
   DECLARE  @CDCLIENTE       VARCHAR(21);
   DECLARE  @DTETLMOVREC     DATETIME;

BEGIN

/*   ----- Inicializando variveis ------*/

   SET @V_COUNTER = 0;

/*   ----- Cursor C_PAGA-----*/

   SET @VRORIGPAG         = 0;
   SET @VRPAGAVENCER      = 0;
   SET @VRPAGVENCIDAS     = 0;
   SET @VRCTPAGARREAL     = 0;
   SET @VRCTPAGARPREV     = 0;
   SET @VRACPAG           = 0;
   SET @VRDCPAG           = 0;
   SET @VRABERTOPAG       = 0;
/*  ---- cURSOR C_RECEB-----*/

   SET  @VRRECEBIDO      = 0;
   SET  @VRABERTOREC     = 0;
   SET  @VRORIGREC       = 0;
   SET  @VRACREC         = 0;
   SET  @VRAREC          = 0;
   SET  @VRREC           = 0;
   SET  @VRDCREC         = 0;
   SET  @VRCTRECARREAL   = 0;
   SET  @VRCTRECPREV     = 0;
   SET  @VRRECAVENCER    = 0;
   SET  @VRRECVENCIDAS   = 0;

   SET @V_MES  =  (CONVERT (VARCHAR, MONTH (@P_DTINI)));
   SET @V_ANO  =  (CONVERT (VARCHAR, YEAR  (@P_DTINI)));

   BEGIN TRAN;
   DELETE FROM ETLCONTAPAG
   WHERE (ANETLPAG > @V_ANO)
   OR (ANETLPAG = @V_ANO AND MEETLPAG >= @V_MES);
   COMMIT TRAN;

   BEGIN TRAN;
   DELETE FROM ETLCONTAREC
   WHERE (ANETLREC > @V_ANO)
   OR (ANETLREC = @V_ANO AND MEETLREC >= @V_MES);
   COMMIT TRAN;

   SET @V_DTINI = CONVERT(DATETIME,('01/'+@V_MES+'/'+@V_ANO),103);

   BEGIN TRAN;
   WHILE (@V_DTINI  <=  @P_DTFINA)
   BEGIN

      SET @V_DTFIM =  DATEADD(MM, 1,@V_DTINI);
      SET @V_DTFIM =  DATEADD(DD,-1,@V_DTFIM);


      DECLARE C_ETL CURSOR FOR
         (
          SELECT
                 FL.CDFILIAL,        FL.CDAREAGERE,          FL.DTINICIALBI,
                 FL.CDSUPERVISOR,    FL.CDGOPERAC,           FL.CDEMPRESA,
                 FL.CDSEGMER
          FROM
               FILIAL FL
          WHERE
               FL.IDFUNCAOFILI IS NULL     --Desconsidera Regionais e Operadores Logsticos
           AND FL.DTINICIALBI  IS NOT NULL --Desconsidera Filiais Sem Data de BI cadastrada
         )
      OPEN C_ETL;
      FETCH NEXT FROM C_ETL INTO
                               @CDFILIAL,      @V_CDAREAGERE,  @V_DTINICIALBI,
                               @V_CDSUPERVISOR,  @V_CDGOPERAC,   @CDEMPRESA,
                               @V_CDSEGMER;

      WHILE (@@FETCH_STATUS = 0) /* Cursor de Filial */
      BEGIN

         /*Incio da condio por data inicial de BI*/

         IF (CONVERT (DATETIME, ('01' + '/' + CONVERT(VARCHAR, MONTH(@V_DTINICIALBI))+'/'+ CONVERT (VARCHAR,
             YEAR(@V_DTINICIALBI)))) <= @V_DTINI)
         BEGIN

            SET   @V_MES   =  CONVERT (VARCHAR, MONTH(@V_DTFIM));
            SET   @V_ANO   =  CONVERT (VARCHAR, YEAR(@V_DTFIM) );
            SET   @V_BIM   =  CONVERT (VARCHAR, (ROUND(((@V_MES - 1) / 2),0) + 1))+' Bim';
            SET   @V_TRI   =  CONVERT (VARCHAR, (ROUND(((@V_MES - 1) / 3),0) + 1))+' Tri';
            SET   @V_SEM   =  CONVERT (VARCHAR, (ROUND(((@V_MES - 1) / 6),0) + 1))+' Sem';

            
      	    DECLARE C_PAGA CURSOR FOR
                (SELECT   
                 CTP.CDFORNECED,
                 CTP.CDEMPRESA,
                 CTP.CDTPCTPAGAR,
                 CTP.CDCLASSFINA,
                 SUM(ISNULL(CTP.VRORIGINAL,0)) AS VRORIG,
                 SUM(ISNULL(CTP.VRAVENCER,0)) AS VRAVENCER,
                 SUM(ISNULL(CTP.VRVENCIDAS,0)) AS VRVENCIDAS,
                 SUM(ISNULL(CTP.VRREAIS,0)) AS VRREAL,
                 SUM(ISNULL(CTP.VRPREV,0)) AS VRPREVISTA,
                 SUM(ISNULL(CTP.VRACRESCIMO,0)) AS VRACRESCIMO,
                 SUM(ISNULL(CTP.VRDESCONTO,0)) AS VRDESCONTO,
                 SUM(ISNULL(CTP.VRCTABERTO,0)) AS VRCTABERTO
            FROM (SELECT CP.CDFILIAL,
                        NF.CDFORNECED,
                        CP.CDEMPRESA,
                        CP.CDTPCTPAGAR,
                        CP.CDCLASSFINA,
                        SUM(ISNULL(CP.VRORIGPAG,0)) AS VRORIGINAL,
                        SUM(ISNULL(CP.VRATUAPAG,0)) AS VREFETIVPAG,
                        SUM(ISNULL(CASE WHEN (CP.DTATUAVENPAG)  >= GETDATE() THEN CP.VRATUAPAG END,0)) AS VRAVENCER,
                        SUM(ISNULL(CASE WHEN (CP.DTATUAVENPAG)  < GETDATE() THEN CP.VRATUAPAG END,0)) AS VRVENCIDAS,
                        (CASE CP.IDSTATPAG WHEN 'B' THEN SUM(ISNULL(CP.VRATUAPAG,0))ELSE 0 END)AS VRREAIS,
                        (CASE NF.IDSTATUS WHEN 'V' THEN SUM(ISNULL(CP.VRATUAPAG,0))ELSE 0 END) AS VRPREV,
                        (CASE TA.IDAJUCTPAG WHEN 'A' THEN SUM(ISNULL(VRAJUSTEPAG,0))ELSE 0 END) AS VRACRESCIMO,
                        (CASE TA.IDAJUCTPAG WHEN 'D' THEN SUM(ISNULL(VRAJUSTEPAG,0))ELSE 0 END) AS VRDESCONTO,
                        (CASE CP.IDSTATPAG WHEN 'A' THEN SUM(ISNULL(CP.VRATUAPAG,0))ELSE 0 END) AS VRCTABERTO
                  
                    FROM CONTAPAGAR CP LEFT JOIN AJCTPAGAR AJ ON (     CP.CDFILIAL          = AJ.CDFILIAL     
	                                                               AND  CP.NRLANCTONF   = AJ.NRLANCTONF   
	                                                               AND  CP.NRSEQVENPAG  = AJ.NRSEQVENPAG  
	                                                               AND  CP.NRPARCELAPAG = AJ.NRPARCELAPAG)
                    LEFT JOIN TIPOAJPAGAR TA ON (AJ.CDAJUCTPAG   = TA.CDAJUCTPAG),
                         NOTAFISCAL NF, TIPOOPERAC OP  
                   WHERE DTATUAVENPAG BETWEEN @V_DTINI AND @V_DTFIM
                     AND CP.CDFILIAL = NF.CDFILIAL
                     AND CP.NRLANCTONF = NF.NRLANCTONF
                     AND CP.CDFILIAL    = @CDFILIAL
                     AND CP.CDEMPRESA IS NOT NULL
                     AND CP.VRATUAPAG > 0
                     AND NOT(NF.IDSTATUS IN('C','G','P','R'))
                     AND OP.CDTIPOOPER = NF.CDTIPOOPER
                     AND OP.IDENTRSAIDOP = 'E'
                  
                   GROUP BY CP.CDFILIAL, NF.CDFORNECED, CP.CDEMPRESA, CP.CDTPCTPAGAR, CP.CDCLASSFINA,NF.IDSTATUS,TA.IDAJUCTPAG,CP.IDSTATPAG) CTP
            GROUP BY CTP.CDFILIAL, CTP.CDFORNECED, CTP.CDEMPRESA, CTP.CDTPCTPAGAR, CTP.CDCLASSFINA)

            OPEN C_PAGA;

            FETCH NEXT FROM C_PAGA INTO
                                  @CDFORNECED,   @CDEMPRESA,  @CDTPCTPAGAR, @CDCLASSFINA,  
                                  @VRORIGPAG, @VRPAGAVENCER, @VRPAGVENCIDAS, @VRCTPAGARREAL, @VRCTPAGARPREV, @VRACPAG,      @VRDCPAG, @VRABERTOPAG;     
						
            WHILE (@@FETCH_STATUS = 0)
            BEGIN
	       SET @V_DTMOV = CONVERT(VARCHAR, @DTETLMOVPAG, 103);
               INSERT INTO ETLCONTAPAG
                 (ANETLPAG,   MEETLPAG,    BIETLPAG,     TRETLPAG,    SEETLPAG,
                  CDFILIAL,   CDFORNECED,  CDEMPRESA,    CDTPCTPAGAR , DTETLMOVPAG,
                  VRETLORIGPAG, VRETLPAGO,  VRETLAPAGAR, VRETLPAGACRE, VRETLPAGDESC,
                  CDCLASSFINA, VRETLPAGVENCIDA, VRETLPAGVENCER, VRETLPAGPREV)
               VALUES
                 (@V_ANO,    @V_MES,      @V_BIM,         @V_TRI,       @V_SEM,
                  @CDFILIAL, @CDFORNECED, @CDEMPRESA,     @CDTPCTPAGAR, @V_DTMOV,
                  @VRORIGPAG, @VRCTPAGARREAL,@VRABERTOPAG, @VRACPAG,  @VRDCPAG,
                  @CDCLASSFINA, @VRPAGVENCIDAS, @VRPAGAVENCER, @VRCTPAGARPREV);

               SET @V_COUNTER = @V_COUNTER + 1;

               IF (@V_COUNTER >= 500)
               BEGIN
                  COMMIT TRAN;
                  BEGIN TRAN;
                  SET @V_COUNTER = 0;
               END;

                FETCH NEXT FROM C_PAGA INTO
                                  @CDFORNECED,   @CDEMPRESA,  @CDTPCTPAGAR, @CDCLASSFINA,
                                  @VRORIGPAG, @VRPAGAVENCER, @VRPAGVENCIDAS, @VRCTPAGARREAL, @VRCTPAGARPREV, @VRACPAG,      @VRDCPAG, @VRABERTOPAG;

            END; /*FIM DO LOOP DE CONTAS A PAGAR/PAGAS*/
            CLOSE C_PAGA;
            DEALLOCATE C_PAGA;

            SET @V_COUNTER = 0;

            DECLARE C_RECEB CURSOR FOR
                  (SELECT
                 CTR.CDCLIENTE,
                 CTR.CDEMPRESA,
                 CTR.CDTPCTRECEB,
                 CTR.CDCLASSFINA,
                 SUM(ISNULL(CTR.VRORIGINAL,0)) AS VRORIG,
                 SUM(ISNULL(CTR.VRAVENCER,0)) AS VRAVENCER,
                 SUM(ISNULL(CTR.VRVENCIDAS,0)) AS VRVENCIDAS,
                 SUM(ISNULL(CTR.VRREAIS,0)) AS VRREAL,
                 SUM(ISNULL(CTR.VRPREV,0)) AS VRPREVISTA,
                 SUM(ISNULL(CTR.VRACRESCIMO,0)) AS VRACRESCIMO,
                 SUM(ISNULL(CTR.VRDESCONTO,0)) AS VRDESCONTO,
                 SUM(ISNULL(CTR.VRCTABERTO,0)) AS VRCTABERTO
            FROM (SELECT  CR.CDFILIAL,
                         NF.CDCLIENTE,
                         CR.CDEMPRESA,
                        CR.CDTPCTRECEB,
                        CR.CDCLASSFINA,
                        SUM(ISNULL(CR.VRORIGREC,0)) AS VRORIGINAL,
                        SUM(ISNULL(CR.VRATUAREC,0)) AS VREFETIVREC,
                        SUM(ISNULL(CASE WHEN (CR.DTATUAVENREC)  >= GETDATE() THEN CR.VRATUAREC END,0)) AS VRAVENCER,
                        SUM(ISNULL(CASE WHEN (CR.DTATUAVENREC)  < GETDATE() THEN CR.VRATUAREC END,0)) AS VRVENCIDAS,
                        (CASE CR.IDSTATREC WHEN 'B' THEN SUM(ISNULL(CR.VRATUAREC,0))ELSE 0 END)AS VRREAIS,
                        (CASE NF.IDSTATUS WHEN 'V' THEN SUM(ISNULL(CR.VRATUAREC,0))ELSE 0 END) AS VRPREV,
                        (CASE TA.IDAJUCTREC WHEN 'A' THEN SUM(ISNULL(VRAJUSTEREC,0))ELSE 0 END) AS VRACRESCIMO,
                        (CASE TA.IDAJUCTREC WHEN 'D' THEN SUM(ISNULL(VRAJUSTEREC,0))ELSE 0 END) AS VRDESCONTO,
                        (CASE CR.IDSTATREC WHEN 'A' THEN SUM(ISNULL(CR.VRATUAREC,0))ELSE 0 END) AS VRCTABERTO

                    FROM CONTARECEBER CR LEFT JOIN AJCTRECEBER AJ ON (     CR.CDFILIAL          = AJ.CDFILIAL
	                                                               AND  CR.NRLANCTONF   = AJ.NRLANCTONF
	                                                               AND  CR.NRSEQVENREC  = AJ.NRSEQVENREC
	                                                               AND  CR.NRPARCELAREC = AJ.NRPARCELAREC)
                    LEFT JOIN TIPOAJRECEBER TA ON (AJ.CDAJUCTREC   = TA.CDAJUCTREC),
                         NOTAFISCAL NF, TIPOOPERAC OP
                    WHERE DTATUAVENREC BETWEEN '01/01/2009' AND '31/01/2009'
                     AND CR.CDFILIAL = NF.CDFILIAL
                     AND CR.NRLANCTONF = NF.NRLANCTONF
                     AND CR.CDFILIAL = @CDFILIAL
                     AND CR.CDEMPRESA IS NOT NULL
                     AND CR.VRATUAREC > 0
                     AND NOT(NF.IDSTATUS IN('C','G','P','R'))
                     AND OP.CDTIPOOPER = NF.CDTIPOOPER
                     AND OP.IDENTRSAIDOP = 'E'

                   GROUP BY CR.CDFILIAL, NF.CDCLIENTE, CR.CDEMPRESA, CR.CDTPCTRECEB, CR.CDCLASSFINA,NF.IDSTATUS,TA.IDAJUCTREC,CR.IDSTATREC) CTR
            GROUP BY CTR.CDFILIAL, CTR.CDCLIENTE, CTR.CDEMPRESA, CTR.CDTPCTRECEB, CTR.CDCLASSFINA)

            OPEN C_RECEB;

            FETCH NEXT FROM C_RECEB INTO
                                 @CDCLIENTE, @CDEMPRESA, @CDTPCTRECEB, @CDCLASSFINA,
                                 @VRORIGREC, @VRRECAVENCER, @VRRECVENCIDAS,@VRCTRECARREAL, @VRCTRECPREV, @VRACREC,
                                 @VRDCREC, @VRABERTOREC;

            WHILE (@@FETCH_STATUS = 0)
            BEGIN
               SET @V_DTMOV = CONVERT(VARCHAR, @DTETLMOVREC, 103);
               INSERT INTO ETLCONTAREC
                  (ANETLREC,   MEETLREC,    BIETLREC,     TRETLREC,    SEETLREC,
                   CDFILIAL,   CDCLIENTE,   CDEMPRESA,    CDTPCTRECEB , DTETLMOVREC,
                   VRETLORIGREC, VRETLRECEB,  VRETLARECEB, VRETLRECACRE, VRETLRECDESC,
                   CDCLASSFINA,VRETLRECVENCIDA,VRETLRECVENCER,VRETLRECPREV)
               VALUES
                  (@V_ANO, @V_MES, @V_BIM, @V_TRI, @V_SEM,
                   @CDFILIAL, @CDCLIENTE, @CDEMPRESA, @CDTPCTRECEB, @V_DTMOV,
                   @VRORIGREC, @VRCTRECARREAL, @VRABERTOREC, @VRACREC, @VRDCREC,
                   @CDCLASSFINA,@VRRECVENCIDAS, @VRRECAVENCER, @VRCTRECPREV );

               SET @V_COUNTER = @V_COUNTER + 1;

               IF (@V_COUNTER >= 500)
               BEGIN
                  COMMIT TRAN;
                  BEGIN TRAN;
                  SET @V_COUNTER = 0;
               END;

            FETCH NEXT FROM C_RECEB INTO
                                 @CDCLIENTE, @CDEMPRESA, @CDTPCTRECEB, @CDCLASSFINA,
                                 @VRORIGREC, @VRRECAVENCER, @VRRECVENCIDAS,@VRCTRECARREAL, @VRCTRECPREV, @VRACREC,   @VRDCREC, @VRABERTOREC

            END ;  /*FIM DO LOOP DE CONTAS A RECEBER/RECEBIDAS*/
            CLOSE C_RECEB;
            DEALLOCATE C_RECEB;

         END; /*Data inicial de BI*/

         FETCH NEXT FROM C_ETL INTO
                               @CDFILIAL,      @V_CDAREAGERE,  @V_DTINICIALBI,
                               @V_CDSUPERVISOR,  @V_CDGOPERAC,   @CDEMPRESA,
                               @V_CDSEGMER;
      END; /*End do loop por filial*/
      CLOSE C_ETL;
      DEALLOCATE C_ETL;
      COMMIT TRAN;
      BEGIN  TRAN;
      SET @V_DTINI = DATEADD(MM, 1, @V_DTINI);
   END; /*END DO LOOP DATA*/
   COMMIT TRAN;


END;
GO


/*REGISTRANDO A PROCEDURE PARA O AGENDADOR DE EVENTOS*/


DECLARE  @V_CDSEQUENCIAL VARCHAR(20);
BEGIN
    SELECT @V_CDSEQUENCIAL = COUNT(*)
    FROM   EVENTOAEV
    WHERE  NMOBJBDEVEN = 'ETL_FINANCEIROGER';

    IF @V_CDSEQUENCIAL = 0     --> S ADICIONA A PROCEDURE SE ELA NO EXISTIR AINDA NO CADASTRO
       BEGIN

       BEGIN TRAN

       SELECT @V_CDSEQUENCIAL = RIGHT(REPLICATE('0','10') + CAST(ISNULL(MAX(RIGHT(REPLICATE('0','10') + CDEVENTOAEV,10))+1,0) as varchar),10)
         FROM EVENTOAEV

       INSERT INTO EVENTOAEV
         (CDEVENTOAEV, NMEVENTOAEV, IDTPEVENAEV, CDOPERINCL, DTINCLEVEN, NMOBJBDEVEN)
       VALUES
         (@V_CDSEQUENCIAL,'Contas do Financeiro','STP',NULL, GETDATE(),'ETL_FINANCEIROGER');

        INSERT INTO PARAMEVENTO
          (CDEVENTOAEV,NMPARAMEVEN,IDDADPARAMEVEN,IDTIPPARAMEVEN,DSPARAMEVEN,IDPARAMNULL,VRTAMPARAM,NRSEQPARAMEVEN)
        VALUES
          (@V_CDSEQUENCIAL,'@P_DTINI','D','E','Data Inicial','N',0,'01');

        INSERT INTO PARAMEVENTO
         (CDEVENTOAEV,NMPARAMEVEN,IDDADPARAMEVEN,IDTIPPARAMEVEN,DSPARAMEVEN,IDPARAMNULL,VRTAMPARAM,NRSEQPARAMEVEN)
        VALUES
         (@V_CDSEQUENCIAL,'@P_DTFINA','D','E','Data Final','N',0,'02');

       COMMIT TRAN;
       END;


    IF @@ERROR <> 0 BEGIN
            ROLLBACK TRAN;
            PRINT 'CRIAO DE EVENTOS AGENDVEIS FALHOU';
    END;
   END;
   

 
GO


/*REGISTRANDO FATOS E DIMENSES*/

BEGIN
   BEGIN TRAN
  ---ETL DE CONTAS A PAGAR/PAGAS---
  EXEC CRIA_FATOS 'ETLCONTAPAG', 'VRETLORIGPAG',  'Vr. original (contas pagas)',  'Financeiro';
  EXEC CRIA_FATOS 'ETLCONTAPAG', 'VRETLPAGO',     'Vr. efetivamente pago',  'Financeiro';
  EXEC CRIA_FATOS 'ETLCONTAPAG', 'VRETLAPAGAR',   'Vr. contas aberto (pagas)',  'Financeiro';
  EXEC CRIA_FATOS 'ETLCONTAPAG', 'VRETLPAGACRE',  'Acrscimos contas pagas',  'Financeiro';
  EXEC CRIA_FATOS 'ETLCONTAPAG', 'VRETLPAGDESC',  'Descontos contas pagas',  'Financeiro';
  EXEC CRIA_FATOS 'ETLCONTAPAG', 'VRETLPAGPREV', 'Vr. contas previstas(PAG)',  'Financeiro';
  EXEC CRIA_FATOS 'ETLCONTAPAG', 'VRETLPAGVENCER', 'Vr. contas a vencer(PAG)',  'Financeiro';
  EXEC CRIA_FATOS 'ETLCONTAPAG', 'VRETLPAGVENCIDA', 'Vr. contas vencidas(PAG)',  'Financeiro';

  EXEC CRIA_DIME 'ETLCONTAPAG',  'CDFILIAL',     'Filial',              'FILIAL',     'CDFILIAL',     'NMFILIAL',     NULL;
  EXEC CRIA_DIME 'ETLCONTAPAG',  'CDEMPRESA',    'Empresa',             'EMPRESA',    'CDEMPRESA',    'NMEMPRESA',    NULL;
  EXEC CRIA_DIME 'ETLCONTAPAG',  'CDTPCTPAGAR',  'Tipo de Conta Paga',       'TIPOCTPAGAR','CDTPCTPAGAR',  'DSTPCTPAGAR',  NULL;
  EXEC CRIA_DIME 'ETLCONTAPAG',  'CDCLASSFINA',  'Classificacao Financeira', 'CLASSFINANC','CDCLASSFINA', 'DSCLASSFINA',NULL;

  EXEC CRIA_DIME 'ETLCONTAPAG',  'CDFORNECED',   'Fornecedor',          'FORNECEDOR', 'CDFORNECED',   'NMFANTFORN',   NULL;
  EXEC CRIA_DIME 'ETLCONTAPAG',  'ANETLPAG',     'Ano',                  NULL,         NULL,           NULL,          NULL;
  EXEC CRIA_DIME 'ETLCONTAPAG',  'MEETLPAG',     'Ms',                  NULL,         NULL,           NULL,          NULL;
  EXEC CRIA_DIME 'ETLCONTAPAG',  'BIETLPAG',     'Bimestre',             NULL,         NULL,           NULL,          NULL;
  EXEC CRIA_DIME 'ETLCONTAPAG',  'TRETLPAG',     'Trimestre',            NULL,         NULL,           NULL,          NULL;
  EXEC CRIA_DIME 'ETLCONTAPAG',  'SEETLPAG',     'Semestre',             NULL,         NULL,           NULL,          NULL;
  EXEC CRIA_DIME 'ETLCONTAPAG',  'DTETLMOVPAG',  'Data da Movimentao', NULL,         NULL,           NULL,          NULL;

   /*ETL DE CONTAS A RECEBER/RECEBIDAS*/
  EXEC CRIA_FATOS 'ETLCONTAREC', 'VRETLORIGREC', 'Vr. original (contas receb.)',  'Financeiro';
  EXEC CRIA_FATOS 'ETLCONTAREC', 'VRETLRECEB',   'Vr. efetivamente recebido',  'Financeiro';
  EXEC CRIA_FATOS 'ETLCONTAREC', 'VRETLARECEB',  'Vr. contas aberto (receb.)',  'Financeiro';
  EXEC CRIA_FATOS 'ETLCONTAREC', 'VRETLRECACRE', 'Acrscimos contas recebidas',  'Financeiro';
  EXEC CRIA_FATOS 'ETLCONTAREC', 'VRETLRECDESC', 'Descontos contas recebidas',  'Financeiro';
  EXEC CRIA_FATOS 'ETLCONTAREC', 'VRETLRECPREV', 'Vr. contas previstas(REC)',  'Financeiro';
  EXEC CRIA_FATOS 'ETLCONTAREC', 'VRETLRECVENCER', 'Vr. contas a vencer(REC)',  'Financeiro';
  EXEC CRIA_FATOS 'ETLCONTAREC', 'VRETLRECVENCIDA', 'Vr. contas vencidas(REC)',  'Financeiro';

  EXEC CRIA_DIME 'ETLCONTAREC',  'CDFILIAL',     'Filial',              'FILIAL',       'CDFILIAL',     'NMFILIAL',     NULL;
  EXEC CRIA_DIME 'ETLCONTAREC',  'CDEMPRESA',    'Empresa',             'EMPRESA',      'CDEMPRESA',    'NMEMPRESA',    NULL;
  EXEC CRIA_DIME 'ETLCONTAREC',  'CDTPCTRECEB',  'Tipo de Conta Recebida',       'TIPOCTRECEBER','CDTPCTRECEB',  'DSTPCTRECEB',  NULL;

  EXEC CRIA_DIME 'ETLCONTAREC',  'CDCLASSFINA',  'Classificacao Financeira', 'CLASSFINANC','CDCLASSFINA', 'DSCLASSFINA',NULL;

  EXEC CRIA_DIME 'ETLCONTAREC',  'CDCLIENTE',    'Cliente',             'CLIENTE',      'CDCLIENTE',    'NMFANTCLIE',   NULL;
  EXEC CRIA_DIME 'ETLCONTAREC',  'ANETLREC',     'Ano',                  NULL,           NULL,           NULL,          NULL;
  EXEC CRIA_DIME 'ETLCONTAREC',  'MEETLREC',     'Ms',                  NULL,           NULL,           NULL,          NULL;
  EXEC CRIA_DIME 'ETLCONTAREC',  'BIETLREC',     'Bimestre',             NULL,           NULL,           NULL,          NULL;
  EXEC CRIA_DIME 'ETLCONTAREC',  'TRETLREC',     'Trimestre',            NULL,           NULL,           NULL,          NULL;
  EXEC CRIA_DIME 'ETLCONTAREC',  'SEETLREC',     'Semestre',             NULL,           NULL,           NULL,          NULL;
  EXEC CRIA_DIME 'ETLCONTAREC',  'DTETLMOVREC',  'Data da Movimentao', NULL,           NULL,           NULL,          NULL;

   COMMIT TRAN;
END;

-- VERSAO --
EXEC ATUVEROBJ 'ETL_FINANCEIROGER','5.05.073';
GO
