/*
Nome: 9810_CDPTRGS_LOG_CDP_VISESPEPRO.SQL

Descrio:
   Trigger para gravar o log das alteraes

Criao:
   17/02/2009 - Henrique Guidi Lobato
Descrio: A trigger insere registros na tabela LOGOPERA a partir das alteraes na tabela
              VISESPEPRO, para verifio de erros */
IF EXISTS(SELECT *
          FROM SYSOBJECTS O, SYSUSERS U
          WHERE O.NAME = 'LOG_CDP_VISESPEPRO' AND
                TYPE   = 'TR'                 AND
                U.UID  = O.UID                AND
                U.NAME = USER)

DROP TRIGGER LOG_CDP_VISESPEPRO
GO


CREATE TRIGGER LOG_CDP_VISESPEPRO
ON VISESPEPRO
FOR UPDATE,INSERT, DELETE
AS
BEGIN

   DECLARE @V_DSREMOTEADDR VARCHAR(15);
   DECLARE @V_DSREMOTEHOST VARCHAR(15);
   DECLARE @V_DSSERVERRDM  VARCHAR(20);
   DECLARE @V_DSSERVMETHOD VARCHAR(30);
   DECLARE @V_DSREMOTEOPER VARCHAR(12);
   DECLARE @V_DESC         VARCHAR(500);
   DECLARE @V_ITPESQ       VARCHAR(80);
   DECLARE @V_NMOPERADOR   VARCHAR(40);
   DECLARE @V_IDCLIEATIV   VARCHAR(1);
   DECLARE @V_NRINCREST    VARCHAR(40);
   DECLARE @V_IDTIPOOPER   VARCHAR(1);

/*VARIVEIS DO CURSOR C_CURSOR*/
   DECLARE @V_ID_TRIGGER       VARCHAR(1);

   DECLARE @V_CDPRODUTO_OLD    VARCHAR(10);
   DECLARE @V_CDESPEPROD_OLD   VARCHAR(10);
   DECLARE @V_CDTIPOVISTO_OLD  VARCHAR(2);
   DECLARE @V_CDOPERADOR_OLD   VARCHAR(12);
   DECLARE @V_DTVISESPEPRO_OLD DATETIME;

   DECLARE @V_CDPRODUTO_NEW    VARCHAR(10);
   DECLARE @V_CDESPEPROD_NEW   VARCHAR(10);
   DECLARE @V_CDTIPOVISTO_NEW  VARCHAR(2);
   DECLARE @V_CDOPERADOR_NEW   VARCHAR(12);
   DECLARE @V_DTVISESPEPRO_NEW DATETIME;

/* IDTIPOOPER - '1' - Incluso, '2' - Alterao, '3' - Excluso*/

   SET @V_DESC       = '';
   SET @V_ITPESQ     = '';
   SET @V_NMOPERADOR = '';
   SET @V_IDCLIEATIV = '';
   SET @V_NRINCREST  = '';
   SET @V_IDTIPOOPER = '';

   EXEC NMUSUARIO  @V_NMOPERADOR;
   EXEC WEBTUNNING @V_DSREMOTEADDR,
                   @V_DSREMOTEHOST,
                   @V_DSSERVERRDM,
                   @V_DSSERVMETHOD,
                   @V_DSREMOTEOPER;

   DECLARE C_CURSOR CURSOR FOR
      SELECT
         'D' IDCOMANDO,
         CDPRODUTO,
         CDESPEPROD,
         CDTIPOVISTO,
         CDOPERADOR,
         DTVISESPEPRO,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL

      FROM
         DELETED
      WHERE
         0 = (SELECT COUNT(*) FROM INSERTED)
      UNION ALL

      SELECT
         'U' IDCOMANDO,
         DELETED.CDPRODUTO,
         DELETED.CDESPEPROD,
         DELETED.CDTIPOVISTO,
         DELETED.CDOPERADOR,
         DELETED.DTVISESPEPRO,
         INSERTED.CDPRODUTO,
         INSERTED.CDESPEPROD,
         INSERTED.CDTIPOVISTO,
         INSERTED.CDOPERADOR,
         INSERTED.DTVISESPEPRO

      FROM
         INSERTED,
         DELETED
      WHERE
         INSERTED.CDPRODUTO  = DELETED.CDPRODUTO

      UNION ALL

      SELECT
        'I' IDCOMANDO,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
        CDPRODUTO,
        CDESPEPROD,
        CDTIPOVISTO,
        CDOPERADOR,
        DTVISESPEPRO

     FROM
        INSERTED
     WHERE
        0 = (SELECT COUNT(*) FROM DELETED)

   OPEN C_CURSOR;
   FETCH NEXT FROM C_CURSOR INTO @V_ID_TRIGGER,

                                 @V_CDPRODUTO_OLD,
                                 @V_CDESPEPROD_OLD,
                                 @V_CDTIPOVISTO_OLD,
                                 @V_CDOPERADOR_OLD,
                                 @V_DTVISESPEPRO_OLD,

                                 @V_CDPRODUTO_NEW,    
                                 @V_CDESPEPROD_NEW,   
                                 @V_CDTIPOVISTO_NEW, 
                                 @V_CDOPERADOR_NEW,
                                 @V_DTVISESPEPRO_NEW;



   WHILE (@@FETCH_STATUS = 0) BEGIN

    IF @V_ID_TRIGGER = 'I' BEGIN

           IF @V_CDPRODUTO_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdProd= ' + ISNULL(@V_CDPRODUTO_NEW,'') + ' ';
           END;

           IF @V_CDESPEPROD_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdEspecificProd= ' + ISNULL(@V_CDESPEPROD_NEW,'') + ' ';
           END;

           IF @V_CDTIPOVISTO_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdTipoVisto= ' + ISNULL(@V_CDTIPOVISTO_NEW,'') + ' ';
           END;

           IF @V_CDOPERADOR_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdOperador= ' + ISNULL(@V_CDOPERADOR_NEW,'') + ' ';
           END;

           IF ISNULL(CONVERT(CHAR, @V_DTVISESPEPRO_NEW, 103), NULL) IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'DtVistoEspecificProd= ' + RTRIM(ISNULL(CONVERT(CHAR, @V_DTVISESPEPRO_NEW, 103), '')) + ' ';
           END;

        SET @V_ITPESQ = @V_CDPRODUTO_NEW + @V_CDESPEPROD_NEW + @V_CDTIPOVISTO_NEW + @V_CDOPERADOR_NEW;

        SET @V_IDTIPOOPER = '1';
     END
     ELSE BEGIN
        IF @V_ID_TRIGGER = 'U' BEGIN

           IF (@V_CDPRODUTO_OLD <> @V_CDPRODUTO_NEW) BEGIN
              SET @V_DESC = @V_DESC + 'CdProd= ' + ISNULL(@V_CDPRODUTO_NEW,'') + ' ';
           END;

           IF (@V_CDESPEPROD_OLD <> @V_CDESPEPROD_NEW) BEGIN
              SET @V_DESC = @V_DESC + 'CdEspecificProd= ' + ISNULL(@V_CDESPEPROD_NEW,'') + ' ';
           END;

           IF (@V_CDTIPOVISTO_OLD <> @V_CDTIPOVISTO_NEW) BEGIN
              SET @V_DESC = @V_DESC + 'CdTipoVisto= ' + ISNULL(@V_CDTIPOVISTO_NEW,'') + ' ';
           END;

           IF (@V_CDOPERADOR_OLD <> @V_CDOPERADOR_NEW) BEGIN
              SET @V_DESC = @V_DESC + 'CdOperador= ' + ISNULL(@V_CDOPERADOR_NEW,'') + ' ';
           END;

           IF (ISNULL(CONVERT(CHAR, @V_DTVISESPEPRO_OLD, 103), 'W') <> ISNULL(CONVERT(CHAR, @V_DTVISESPEPRO_NEW, 103), 'W')) BEGIN
              SET @V_DESC = @V_DESC + 'DtVistoEspecificProd= ' + RTRIM(ISNULL(CONVERT(CHAR, @V_DTVISESPEPRO_NEW, 103), '')) + ' ';
           END;

           SET @V_ITPESQ = @V_CDPRODUTO_NEW + @V_CDESPEPROD_NEW + @V_CDTIPOVISTO_NEW + @V_CDOPERADOR_NEW;

           SET @V_IDTIPOOPER = '2';

        END;

        IF @V_ID_TRIGGER = 'D'  BEGIN

           IF @V_CDPRODUTO_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdProd= ' + ISNULL(@V_CDPRODUTO_OLD,'') + ' ';
           END;

           IF @V_CDESPEPROD_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdEspecificProd= ' + ISNULL(@V_CDESPEPROD_OLD,'') + ' ';
           END;

           IF @V_CDTIPOVISTO_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdTipoVisto= ' + ISNULL(@V_CDTIPOVISTO_OLD,'') + ' ';
           END;

           IF @V_CDOPERADOR_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdOperador= ' + ISNULL(@V_CDOPERADOR_OLD,'') + ' ';
           END;

           IF ISNULL(CONVERT(CHAR, @V_DTVISESPEPRO_OLD, 103), NULL) IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'DtVistoEspecificProd= ' + RTRIM(ISNULL(CONVERT(CHAR, @V_DTVISESPEPRO_OLD, 103), '')) + ' ';
           END;

        SET @V_ITPESQ = @V_CDPRODUTO_OLD + @V_CDESPEPROD_OLD + @V_CDTIPOVISTO_OLD + @V_CDOPERADOR_OLD;

           SET @V_IDTIPOOPER = '3';
        END;
     END;

     IF NOT (@V_DESC IS NULL) BEGIN

        INSERT INTO LOGOPERA ( NMTABELA, DTOPERACAO, NMRESPOPER,
                               IDTIPOOPER,   DSOPERACAO, CDPESQITEM,
                               DSRDMUSUOPER, DSENDUSUOPER, DSNMUSUOPER,
                               DSMETUSUOPER, CDORESPOPER)
                    VALUES   ('VISESPEPRO', GETDATE() ,    ISNULL(@V_NMOPERADOR,' '),
                               @V_IDTIPOOPER,   @V_DESC, @V_ITPESQ,
                               @V_DSSERVERRDM, @V_DSREMOTEADDR,  @V_DSREMOTEHOST,
                               @V_DSSERVMETHOD,   @V_DSREMOTEOPER);
     END;

   FETCH NEXT FROM C_CURSOR INTO @V_ID_TRIGGER,

                                 @V_CDPRODUTO_OLD,    
                                 @V_CDESPEPROD_OLD,   
                                 @V_CDTIPOVISTO_OLD, 
                                 @V_CDOPERADOR_OLD, 
                                 @V_DTVISESPEPRO_OLD,

                                 @V_CDPRODUTO_NEW,    
                                 @V_CDESPEPROD_NEW,   
                                 @V_CDTIPOVISTO_NEW, 
                                 @V_CDOPERADOR_NEW, 
                                 @V_DTVISESPEPRO_NEW;

   END;

   CLOSE      C_CURSOR;
   DEALLOCATE C_CURSOR;

END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'LOG_CDP_VISESPEPRO','5.07.000';
GO
